#ifndef OPTIONDIALOG_H
#define OPTIONDIALOG_H

#include <QDialog>
#include <QSettings>

class QComboBox;
class QVBoxLayout;
class QCheckBox;

#define DEFAULT_ROW_HEIGHT 24

class OptionDialog : public QDialog
{
    Q_OBJECT
public:
    explicit OptionDialog(QWidget *parent, QSettings& set);
    ~OptionDialog ();

signals:

public slots:
private slots:
    void orderControl (QString);
    void headphoneSenseToggle (bool);
private:
    void    setupUi ();
    QSettings& settings;
    QComboBox* orient;
    QComboBox* buttonSize;
    QComboBox* rowHeight;
    QCheckBox* hpsense;
    QList<QCheckBox*> headerCbs;
    QStringList availableHeaders;
    QVBoxLayout *headerLayout;
};

#endif // OPTIONDIALOG_H
